@@ -22,19 +22,7 @@
 #' @return A \code{MetaCommunity} object (see \code{\link[entropart]{entropart-package}}).
 #' @examples
 #' \dontrun{
-#' data("loremIpsum")
-#' loremIpsum01 <- loremIpsum[1:10]
-#' loremIpsum02 <- loremIpsum[11:20]
-#' loremIpsum03 <- loremIpsum[21:30]
-#' subDir <- "RESULTS"
-#' dir.create(file.path(getwd(), subDir), showWarnings = FALSE)
-#' write(x = loremIpsum01, file = "RESULTS/loremIpsum01.txt")
-#' write(x = loremIpsum02, file = "RESULTS/loremIpsum02.txt")
-#' write(x = loremIpsum03, file = "RESULTS/loremIpsum03.txt")
-#' wordOccuDF <- getwordOccuDF(mywd = paste0(getwd(), "/RESULTS"), 
-#'   excludeSW = FALSE)
-#' file.remove(list.files(full.names = TRUE, 
-#'   path = paste0(getwd(), "/RESULTS"), pattern = "loremIpsum"))
+#' data("wordOccuDF")
 #' doMetacomEntropart(wordF = wordOccuDF)
 #' }
 #' @export
@@ -44,8 +32,10 @@
 doMetacomEntropart <- function(wordF, getPlot = c(TRUE, TRUE, TRUE, TRUE), 
   getTextSink = c(TRUE, TRUE, TRUE, TRUE), mwidth = 800, mheight = 800, formatType = "png"){
   ## create RESULTS folder
-  subDir <- "RESULTS"
-  dir.create(file.path(getwd(), subDir), showWarnings = FALSE)
+  if(sum(getPlot) > 0 | sum(getTextSink) > 0){
+    subDir <- "RESULTS"
+    dir.create(file.path(getwd(), subDir), showWarnings = FALSE)
+  }
   ## make entropart analysis
   metacomDB <- wordF
   names(metacomDB)[1] <- "Species"
